@@ -92,6 +92,44 @@ skip_if_mocked("can't check country when mocking is in place", 1, sub {
 $number = Number::Phone->new('+447693912345');
 ok($number->is_pager(), "pagers correctly identified");
 
+# see https://github.com/DrHyde/perl-modules-Number-Phone/issues/112
+# checked on 2022-12-24
+# next check due 2023-06-01 (semi-annually)
+subtest "0800 716 range has the wrong length, OFCOM says 10 digits but 0800 716 598 is diallable" => sub {
+    $number = Number::Phone->new('+44800716598'); # used by Barclays
+    isa_ok(
+        $number,
+        (is_mocked_uk()
+            ? 'Number::Phone::StubCountry::MOCK'
+            : 'Number::Phone::UK'
+        )
+    );
+    ok($number->is_tollfree(), "valid 9 digit number in a range supposedly for 10 digit numbers");
+
+    $number = Number::Phone->new(
+        (is_mocked_uk() ? 'MOCK' : 'UK'),
+        '0800716598'
+    );
+    isa_ok(
+        $number,
+        (is_mocked_uk()
+            ? 'Number::Phone::StubCountry::MOCK'
+            : 'Number::Phone::UK'
+        )
+    );
+    ok($number->is_tollfree(), "valid 9 digit number (national format) in a range supposedly for 10 digit numbers");
+
+    # this is invalid, it's a digit appended to the above, but this may
+    # be a mixed 9 and 10 digit range, so test it to make sure the length
+    # check passes
+    $number = Number::Phone->new('+448007165980');
+    ok($number->is_tollfree(), "10 digit number also in that range");
+
+    # this is invalid, it's too short, in that mixed range
+    $number = Number::Phone->new('+4480071659');
+    is($number, undef, "too short number doesn't validate");
+};
+
 $number = Number::Phone->new('+44800001012');
 ok($number->is_tollfree(), "toll-free numbers with significant F digit correctly identified");
 # 0500 is Quarantined
@@ -112,11 +150,8 @@ skip_if_mocked("libphonenumber doesn't know about location/operators/network-ser
   $number = Number::Phone->new('+445588301234');
   ok($number->is_corporate(), "corporate numbers correctly identified");
 
-  $number = Number::Phone->new('+448200803456');
-  ok($number->is_network_service(), "network service numbers correctly identified");
-
   $number = Number::Phone->new('+448450033845');
-  is($number->operator(), 'GCI Network Solutions Limited', "operators correctly identified");
+  is($number->operator(), 'GCI Network Solutions Ltd', "operators correctly identified");
 
   $number = Number::Phone->new('+442087712924');
   subtest "geo numbers have correct location" => sub {
@@ -207,7 +242,7 @@ skip_if_mocked("libphonenumber disagrees with me about formatting mobile numbers
 $number = Number::Phone->new('+447500000000');
 ok($number->is_mobile(), "075 mobiles correctly identified");
 skip_if_mocked("libphonenumber doesn't do operators", 1, sub {
-  is($number->operator(), 'Vodafone Uk Ltd', "075 mobiles have right operator");
+  is($number->operator(), 'Vodafone Limited', "075 mobiles have right operator");
 });
 skip_if_mocked("libphonenumber disagrees with me about formatting mobile numbers", 1, sub {
   is($number->format(), '+44 7500 000000', "075 mobiles are formatted OK");
@@ -265,6 +300,11 @@ foreach my $invalid (qw(+4427593934500 +4420877129200 +4411320316000 +4411332500
     $number = Number::Phone->new($invalid);
     ok(!defined($number), "$invalid is invalid (too long)");
 }
+foreach my $invalid (qw(+444000000000 +445025259012 +446000000000)) {
+    $number = Number::Phone->new($invalid);
+    (my $range = $invalid) =~ s/^(\+44....).*/$1/;
+    is($number, undef, "Invalid number identified, $range is not in a valid range");
+}
 
 foreach my $tuple (
   [ 'Number::Phone'     => '+441954202020', '+44 1954 202020' ],
@@ -279,8 +319,9 @@ foreach my $tuple (
   });
 }
 
-note("is_drama");
-my @drama_numbers = (
+skip_if_mocked("Stubs don't support is_drama", 51, sub {
+    note("is_drama");
+    foreach my $dn (
         ['Leeds',            'geographic',  '+44 113 496 0553', '+44 113 496 0494'],
         ['Sheffield',        'geographic',  '+44 114 496 0445'],
         ['Nottingham',       'geographic',  '+44 115 496 0881'],
@@ -291,7 +332,7 @@ my @drama_numbers = (
         ['Edinburgh',        'geographic',  '+44 131 496 0107'],
         ['Glasgow',          'geographic',  '+44 141 496 0297'],
         ['Liverpool',        'geographic',  '+44 151 496 0787'],
-        ['Mahchester',       'geographic',  '+44 161 496 0508'],
+        ['Manchester',       'geographic',  '+44 161 496 0508'],
         ['London',           'geographic',  '+44 20 7946 0364', '+44 20 7946 0885'],
         ['Tyneside',         'geographic',  '+44 191 498 0228'],
         ['Cardiff',          'geographic',  '+44 29 2018 0678'],
@@ -301,31 +342,23 @@ my @drama_numbers = (
         ['Freephone',        'tollfree',    '+44 8081 570576', '+44 8081 570044'],
         ['Premium Rate',     'specialrate', '+44 909 879 0845'],
         ['UK-Wide',          'specialrate', '+44 3069 990965'],
-);
-foreach my $dn (@drama_numbers) {
-     my $area = shift @{$dn};
-     my $type = shift @{$dn};
-     foreach my $num (@{$dn}) {
-         my $phone = Number::Phone->new($num);
-         skip_if_mocked("Stubs don't support is_drama", 1, sub {
+    ) {
+         my $area   = shift(@{$dn});
+         my $method = 'is_'.shift(@{$dn});
+         foreach my $num (@{$dn}) {
+             my $phone = Number::Phone->new($num);
              ok($phone->is_drama(), "$area drama number $num is_drama");
-         });
-         my $method = "is_$type";
-         skip_if_mocked("Stubs don't always support is_* for is_drama", 1, sub {
              ok($phone->$method(), "$area drama number $num $method");
-         });
-         if($area eq 'Mobile') {
-             is($phone->country(), 'UK', "$num is UK-wide is_drama, not Jersey");
+             if($area eq 'Mobile') {
+                 is($phone->country(), 'UK', "$num is UK-wide is_drama, not Jersey");
+             }
          }
-     }
-}
-foreach my $number (qw(+447979866975 +442087712924)) {
-     skip_if_mocked("Stubs don't support is_drama", 1, sub {
+    }
+    foreach my $number (qw(+447979866975 +442087712924)) {
          ok(defined(Number::Phone->new($number)->is_drama()) &&
             !Number::Phone->new($number)->is_drama(),
             "normal number $number is not is_drama");
-     });
-}
-
+    }
+});
 
 1;
